@@ -15,8 +15,11 @@ from compose_companion.functions import (
     container_start,
     container_pause,
     container_unpause,
+    container_create,
     container_up,
     print_config,
+    backup_volumes,
+    restore_volumes
 )
 
 app = typer.Typer()
@@ -51,7 +54,6 @@ def main(ctx: typer.Context):
     else:
         Configurations()
 
-
 @app.command()
 def up(
     targets: Optional[List[str]] = typer.Argument(
@@ -175,6 +177,28 @@ def stop(
         container_stop(container)
 
 
+@app.command()
+def create(
+    targets: Optional[List[str]] = typer.Argument(
+        None,
+        help="Containers in which to run the command. If no targets are passed, runs for all containers.",
+        autocompletion=autocomplete_containers,
+    ),
+):
+    """
+    Creates targeted containers.
+    If no target is defined, creates all containers.
+    Equivalent to `docker compose create`.
+    """
+    services = Configurations().services
+    if not targets:
+        for container in services:
+            container_create(container)
+        return
+    for container in targets:
+        container_create(container)
+
+
 @app.command()
 def down(
     targets: Optional[List[str]] = typer.Argument(
@@ -184,7 +208,8 @@ def down(
     ),
     remove_volumes: Optional[bool] = typer.Option(
         False,
-        "--remove-volumes",
+        "-v",
+        "--volumes",
         help="Remove any anonymous volumes attached to the containers. Equivalent do docker compose -v/--volumes option.",
     ),
     confirmation: bool = typer.Option(
@@ -305,6 +330,76 @@ def ps(
     run(f"docker compose -f {compose_file} ps {' '.join(targets)} -a={include_stopped}")
 
 
+@app.command()
+def backup(
+    targets: Optional[List[str]] = typer.Argument(
+        None,
+        help="Containers in which to run the command. If no targets are passed, runs for all containers.",
+        autocompletion=autocomplete_containers,
+    ),
+    volumes: Optional[List[str]] = typer.Option(
+        None,
+        "-v",
+        "--volumes",
+        help="Volumes for which to run the command. If no targets are passed, runs for all volumes.",
+    ),
+    backup_dir: Optional[str] = typer.Option(
+        None,
+        "-d",
+        "--backup-dir",
+        help="Directory in which to save the backup. If not specified, backup will be saved on <current_path>/compose-backup",
+    ),
+):
+    """
+    Backs up named volumes for containers.
+    If no target is defined, Backs up volumes for all containers.
+    """
+    compose_file = Configurations().compose_file
+    services = Configurations().services
+
+    if not targets:
+        for container in services:
+            backup_volumes(container, volumes, backup_dir)
+        return
+    for container in targets:
+        backup_volumes(container, volumes, backup_dir)
+
+
+@app.command()
+def restore(
+    targets: Optional[List[str]] = typer.Argument(
+        None,
+        help="Containers in which to run the command. If no targets are passed, runs for all containers.",
+        autocompletion=autocomplete_containers,
+    ),
+    volumes: Optional[List[str]] = typer.Option(
+        None,
+        "-v",
+        "--volumes",
+        help="Volumes for which to run the command. If no targets are passed, runs for all volumes.",
+    ),
+    backup_dir: Optional[str] = typer.Option(
+        None,
+        "-d",
+        "--backup-dir",
+        help="Directory from which to fetch the backup. If not specified, backup will be fetched from <current_path>/compose-backup",
+    ),
+):
+    """
+    Restores previously backed up named volumes for containers.
+    If no target is defined, Restores volumes for all containers.
+    """
+    compose_file = Configurations().compose_file
+    services = Configurations().services
+
+    if not targets:
+        for container in services:
+            restore_volumes(container, volumes, backup_dir)
+        return
+    for container in targets:
+        restore_volumes(container, volumes, backup_dir)
+
+
 @app.command()
 def config(
     key: Optional[str] = typer.Argument(
