@@ -98,10 +98,10 @@ class Configurations:
         local_compose_file_yml = Path("docker-compose.yml").resolve()
 
         if local_compose_file_yaml.is_file():
-            self.compose_file = str(local_compose_file)
+            self.compose_file = str(local_compose_file_yaml)
             return
         elif local_compose_file_yml.is_file():
-            self.compose_file = str(local_compose_file)
+            self.compose_file = str(local_compose_file_yml)
             return
 
         compose_file_input = typer.prompt(
@@ -121,10 +121,10 @@ class Configurations:
         local_companion_file_yml = Path("compose-companion.yml").resolve()
 
         if local_companion_file_yaml.is_file():
-            self.companion_file = str(local_companion_file)
+            self.companion_file = str(local_companion_file_yaml)
             return
         if local_companion_file_yml.is_file():
-            self.companion_file = str(local_companion_file)
+            self.companion_file = str(local_companion_file_yml)
             return
         elif Path(self.compose_file).is_file():
             use_compose = typer.confirm(
